@@ -1,6 +1,6 @@
 #' Connect and parse UniProt Pathology_Biotech information.
 #'
-#' The function is work to retrieve Pathology_Biotech data from UniProt for 
+#' The function is work to retrieve Pathology_Biotech data from UniProt for
 #' a list of proteins accessions.For more information about what included in the
 #' Pathology_Biotech data see https://www.uniprot.org/help/uniprotkb_column_names.
 #'
@@ -19,17 +19,13 @@
 #'
 #' @export
 #'
-#' @author Mohmed Soudy and Ali Mostafa
+#' @author Mohmed Soudy \email{Mohamed.soudy@57357.com} and Ali Mostafa \email{ali.mo.anwar@std.agr.cu.edu.eg}
 
 
 GetPathology_Biotech<- function(ProteinAccList , directorypath = NULL){
 
   # Pathology_Biotech information to be collected
-  columns <- c("comment(ALLERGEN)","comment(BIOTECHNOLOGY)",
-               "comment(DISRUPTION PHENOTYPE)","comment(DISEASE)","comment(PHARMACEUTICAL)",
-               "comment(TOXIC DOSE)")
-
-
+  columns <- c("comment(ALLERGEN),comment(BIOTECHNOLOGY),comment(DISRUPTION PHENOTYPE),comment(DISEASE),comment(PHARMACEUTICAL),comment(TOXIC DOSE)")
   baseUrl <- "http://www.uniprot.org/uniprot/"
   ProteinInfoParsed_total = data.frame()
   for (ProteinAcc in ProteinAccList)
