@@ -17,37 +17,23 @@
 #'
 #' @note The function also, Creates a csv file with the retrieved information.
 #'
-#' @author Mohmed Soudy and Ali Mostafa
+#' @author Mohmed Soudy \email{Mohamed.soudy@57357.com} and Ali Mostafa \email{ali.mo.anwar@std.agr.cu.edu.eg}
 #'
 #' @export
 
 GetSequences <- function(ProteinAccList, directorypath = NULL){
 
   # Sequences information to be collected
-  columns <- c("fragment","encodedon","comment(ALTERNATIVE PRODUCTS)",
-               "comment(ERRONEOUS GENE MODEL PREDICTION)",
-               "comment(ERRONEOUS INITIATION)","comment(ERRONEOUS TERMINATION)",
-               "comment(ERRONEOUS TRANSLATION)","comment(FRAMESHIFT)",
-               "comment(MASS SPECTROMETRY)","comment(POLYMORPHISM)",
-               "comment(RNA EDITING)","comment(SEQUENCE CAUTION)",
-               "length","mass","sequence","feature(ALTERNATIVE SEQUENCE)",
-               "feature(NATURAL VARIANT)","feature(NON ADJACENT RESIDUES)",
-               "feature(NON STANDARD RESIDUE)","feature(NON TERMINAL RESIDUE)",
-               "feature(SEQUENCE CONFLICT)","feature(SEQUENCE UNCERTAINTY)",
-               "version(sequence)")
-
-
+  columns <- c("fragment,encodedon,comment(ALTERNATIVE PRODUCTS),comment(ERRONEOUS GENE MODEL PREDICTION),comment(ERRONEOUS INITIATION),comment(ERRONEOUS TERMINATION),comment(ERRONEOUS TRANSLATION),comment(FRAMESHIFT),comment(MASS SPECTROMETRY),comment(POLYMORPHISM),comment(RNA EDITING),comment(SEQUENCE CAUTION),length,mass,sequence,feature(ALTERNATIVE SEQUENCE),feature(NATURAL VARIANT),feature(NON ADJACENT RESIDUES),feature(NON STANDARD RESIDUE),feature(NON TERMINAL RESIDUE),feature(SEQUENCE CONFLICT),feature(SEQUENCE UNCERTAINTY),version(sequence)")
   baseUrl <- "http://www.uniprot.org/uniprot/"
   ProteinInfoParsed_total = data.frame()
   for (ProteinAcc in ProteinAccList)
   {
     #to see if Request == 200 or not
     Request <- GET(paste0(baseUrl , ProteinAcc,".xml"))
-
     #this link return information in tab formate (format = tab)
     #columns = what to return from all of the information (see: https://www.uniprot.org/help/uniprotkb_column_names)
     ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",columns)
-
     RequestUrl <- paste0(baseUrl , ProteinName_url)
     if (Request$status_code == 200){
       # parse the information in DataFrame
@@ -61,7 +47,6 @@ GetSequences <- function(ProteinAccList, directorypath = NULL){
     }else {
       HandleBadRequests(Request$status_code)
     }
-
   }
   if(!is.null(directorypath))
   {
